instrumenttools.BassClarinet
============================

.. abjad-lineage:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet

.. autoclass:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassClarinet.BassClarinet.BassClarinet.__repr__
   :noindex:
